# External API


```{eval-rst}
.. module:: scanpy.external
```

```{warning}
We are no longer accepting new tools into `scanpy.external`.
Instead, please submit your tool to the [scverse ecosystem package listing](https://scverse.org/packages/#ecosystem).
```

```{note}
For tools that integrate well with scanpy and anndata, see:
* The [scverse ecosystem](https://scverse.org/packages/#ecosystem)
* Scanpy's ecosystem {doc}`ecosystem page <../ecosystem>`
```

Import Scanpy's wrappers to external tools as:

```
import scanpy.external as sce
```


```{toctree}
:maxdepth: 2

preprocessing
tools
plotting
exporting
```
